// VERTICAL STRETCH SHADER
// namor.noditz@hkv.de
// 2024-04-23
// Tested with MPC-HC 2.1.0 and MADVR 
// Blackbar Detection and Crop must be enabled in MADVR, to get the real aspect ratio without blackbars !!

// Adapt these 3 parameters for your needs
const static float arscreen = 2.1;    // Width auf my Screen
const static float zoom2width = 1.8;  // Zoom to width before Streching
const static float centerwidth = 0.2; // Center width without Stretching


//Parameters for matching function pot // do not change !!
const static float a = 0.240;

const static float b =  6.000;
const static float c = 0.760;
const static float k1 = 2.000;
 
sampler s0 : register(s0);
float4 p0 :  register(c0);

#define width  (p0[0])
#define height (p0[1])

float4 main(float2 tex : TEXCOORD0) : COLOR {
	
  float arsource = width / height;  
  
  if ( arscreen > arsource ) { 
	  
	  float vsize = 1.0;    
	  
	  if ( zoom2width > arsource ) { vsize = zoom2width / arsource ; }   
	  
	  float vfact = (arsource / arscreen) * vsize;
	  float k2 = a * pow(vfact, b) + c;
	  float pot = (k1*(arsource - centerwidth  )/(arscreen - centerwidth * vsize )*vsize-k2);

	  float arsource_ = arsource  * vsize;
	  float factcenter = arscreen / arsource_ ;
	  float sidesource = (arsource_ - centerwidth * vsize ) / 2 / arsource_;
	  float sidescreen = (arscreen - centerwidth * vsize ) / 2 / arscreen;
	  float factside = sidesource / sidescreen;
	  float blackbarsize = (1 - arsource / arscreen ) / 2 ;

	  tex.x = tex.x < sidescreen       ? 0 + (0 + tex.x) * ((0 + tex.x) / sidescreen * (1 - pot) + pot) * factside : (
			  tex.x < (1 - sidescreen) ? tex.x * factcenter + (1 - factcenter) / 2: (
										 1 - (1 - tex.x) * ((1 - tex.x) / sidescreen * (1 - pot) + pot) * factside )							 
	  ); 
	  
	  tex.y = tex.y < blackbarsize       ? -1 : (
			  tex.y < (1 - blackbarsize) ? tex.y * factcenter + (1 - factcenter) / 2 : (
										   -1 )
	  ); 
			  
  };
  
  return tex.y >= 0.0 && tex.y <= 1.0 ? tex2D(s0, tex).rgbb : float4(0,0,0,0);  

}
